pub enum DataError {
Show 18 variants
AttrUnsupported(&'static str),
AttrNotFound,
IndexUnsupported(&'static str),
StrKeyUnsupported(&'static str),
IntKeyUnsupported(&'static str),
IndexNotFound,
OutputUnsupported(&'static str),
OutputError(&'static str),
UnknownValidator(String),
RegexValidationError(String, String),
BoolUnsupported(&'static str),
NumberUnsupported(&'static str),
ComparisonUnsupported(&'static str),
IterationUnsupported(&'static str),
PairIterationUnsupported(&'static str),
VariableNotFound(String),
Incomparable(&'static str, &'static str),
Custom(Box<dyn Error>),
// some variants omitted
}Expand description
This error is used to describe invalid variable usage in template
Variants
AttrUnsupported(&'static str)
Unsupported get attribute operation
AttrNotFound
No suche attribute on this object
IndexUnsupported(&'static str)
Unsupported subscription operation
StrKeyUnsupported(&'static str)
Unsupported using this object as a key in dictionary subscription
IntKeyUnsupported(&'static str)
Unsupported using this object as a key in array subscription
IndexNotFound
No such index on this object
OutputUnsupported(&'static str)
The object can’t be output
OutputError(&'static str)
The object can’t be output
UnknownValidator(String)
Named validator is not known
RegexValidationError(String, String)
Output did not match regex
BoolUnsupported(&'static str)
The object can’t be boolean
NumberUnsupported(&'static str)
The object can’t be a number
ComparisonUnsupported(&'static str)
The object can’t be compared to
IterationUnsupported(&'static str)
The object can’t be iterated over
PairIterationUnsupported(&'static str)
The object can’t be iterated over by pairs
VariableNotFound(String)
Variable or attribute not found
Incomparable(&'static str, &'static str)
Incomparable types
Custom(Box<dyn Error>)
Custom error